(TeX-add-style-hook "Implementation"
 (lambda ()
    (LaTeX-add-bibliographies
     "lme4")
    (LaTeX-add-labels
     "sec:example"
     "fig:Raildotplot"
     "eq:1"
     "eq:lmm"
     "sec:fitt-model-exam"
     "eq:Astar"
     "eq:2"
     "fig:devcomp"
     "fig:devcomp2"
     "sec:multiple-re"
     "fig:sleepxyplot"
     "fig:ALstruct"
     "sec:nested"
     "fig:Oatsxy"
     "fig:Om1struct"
     "fig:Om1astruct"
     "fig:sm2struct"
     "fig:Om2struct"
     "sec:non-nested"
     "fig:Sm1struct"
     "sec:role-group-fact"
     "eq:blockDiag"
     "eq:blockblock"
     "eq:STinner"
     "sec:non-singular"
     "eq:bstar"
     "eq:bstarb"
     "eq:Zstar"
     "eq:Zb"
     "eq:bstarmode"
     "eq:bstarbeta"
     "eq:Amatrix"
     "eq:fillPerm"
     "eq:Lmat"
     "eq:soln"
     "eq:dtheta"
     "eq:3"
     "sec:singular"
     "sec:reml-estimates"
     "eq:REMLdev"
     "sec:GLMMs"
     "sec:gener-line-models"
     "eq:glmlink"
     "eq:glmlinkinv"
     "eq:logit"
     "eq:logitInv"
     "sec:gener-line-mixed"
     "eq:glmmLP"
     "eq:random-effects-dist"
     "eq:marginalDens"
     "eq:conditionalmodes"
     "sec:deta-pirls-algor"
     "eq:rthLinPred"
     "eq:adjdep"
     "eq:IRLSupdate"
     "eq:conditionalmin"
     "eq:PIRLSupdate"
     "eq:PIRLSbstarupdate"
     "eq:varcov"
     "sec:deta-lapl-appr"
     "eq:LaplaceApprox"
     "app:notation"
     "sec:randomVariables"
     "sec:dimensions")
    (TeX-add-symbols
     '("package" 1)
     '("code" 1)
     "trans"
     "invtrans")
    (TeX-run-style-hooks
     "natbib"
     "authoryear"
     "round"
     "bm"
     "amsmath"
     "Sweave"
     "latex2e"
     "art12"
     "article"
     "12pt")))

